package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TextMessage;

/**
 * 短信设置Service接口
 * 
 * @author ruoyi
 * @date 2021-07-20
 */
public interface ITextMessageService 
{
    /**
     * 查询短信设置
     * 
     * @param id 短信设置ID
     * @return 短信设置
     */
    public TextMessage selectTextMessageById(Long id);

    /**
     * 查询短信设置列表
     * 
     * @param textMessage 短信设置
     * @return 短信设置集合
     */
    public List<TextMessage> selectTextMessageList(TextMessage textMessage);

    /**
     * 新增短信设置
     * 
     * @param textMessage 短信设置
     * @return 结果
     */
    public int insertTextMessage(TextMessage textMessage);

    /**
     * 修改短信设置
     * 
     * @param textMessage 短信设置
     * @return 结果
     */
    public int updateTextMessage(TextMessage textMessage);

    /**
     * 批量删除短信设置
     * 
     * @param ids 需要删除的短信设置ID
     * @return 结果
     */
    public int deleteTextMessageByIds(Long[] ids);

    /**
     * 删除短信设置信息
     * 
     * @param id 短信设置ID
     * @return 结果
     */
    public int deleteTextMessageById(Long id);
}
